from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Boolean, String, Directory, File

Dialign_Tx_V0_1_0 = CommandToolBuilder(tool="dialign_tx", base_command=["dialign-tx"], inputs=[ToolInput(tag="in_debugmode_debug_statements", input_type=Boolean(optional=True), prefix="-d", doc=InputDocumentation(doc="Debug-Mode  [DEFAULT 0]\n0 no debug statements\n1 debugs the current phase of the processing\n2 very loquacious debugging\n5 hardcore debugging")), ToolInput(tag="in_maximum_amount_input", input_type=Boolean(optional=True), prefix="-s", doc=InputDocumentation(doc="maximum amount of input sequences [DEFAULT 5000]")), ToolInput(tag="in_maximum_number_characters", input_type=Boolean(optional=True), prefix="-a", doc=InputDocumentation(doc="maximum number of characters per line in a FASTA file [DEFAULT 100]")), ToolInput(tag="in_maximum_amount_printing", input_type=Boolean(optional=True), prefix="-c", doc=InputDocumentation(doc="maximum amount of characters per line when printing a sequence\n[DEFAULT 80]")), ToolInput(tag="in_sensitivity_mode_aligned", input_type=Boolean(optional=True), prefix="-l", doc=InputDocumentation(doc="sensitivity mode, the higher the level the less likely\nspurious random fragments are aligned in local alignments\n[DEFAULT 0]\n0 switched off\n1 level-1, reduced sensitivity\n2 level-2, strongly reduced sensitivity")), ToolInput(tag="in_score_matrix_file", input_type=Boolean(optional=True), prefix="-m", doc=InputDocumentation(doc="score matrix file name (in the configuration directory)\n[DEFAULT PROTEIN: BLOSUM.scr]\n[DEFAULT DNA: dna_matrix.scr]")), ToolInput(tag="in_defines_minimum_weight", input_type=Boolean(optional=True), prefix="-w", doc=InputDocumentation(doc="defines the minimum weight when the weight formula is changed\nto 1-pow(1-prob, factor) [DEFAULT 0.000000065]")), ToolInput(tag="in_probability_distribution_file", input_type=Boolean(optional=True), prefix="-p", doc=InputDocumentation(doc="probability distribution file name (in the configuration\ndirectory)\n[DEFAULT PROTEIN: BLOSUM.diag_prob_t10]\n[DEFAULT DNA: dna_diag_prob_100_exp_550000]")), ToolInput(tag="in_add_prevent_values", input_type=Boolean(optional=True), prefix="-v", doc=InputDocumentation(doc="add to each score (to prevent negative values) [DEFAULT 0]")), ToolInput(tag="in_threshold_low_alignment", input_type=Boolean(optional=True), prefix="-t", doc=InputDocumentation(doc="'even' threshold for low score for sequences alignment\n[DEFAULT PROTEIN: 4]\n[DEFAULT DNA: 0]")), ToolInput(tag="in_maximum_number_consecutive", input_type=Boolean(optional=True), prefix="-n", doc=InputDocumentation(doc="maximum number of consecutive positions for window containing\nlow scoring positions\n[DEFAULT PROTEIN: 4]\n[DEFAULT DNA: 4]")), ToolInput(tag="in_global_minimum_fragment", input_type=Boolean(optional=True), prefix="-g", doc=InputDocumentation(doc="global minimum fragment length for stop criterion\n[DEFAULT PROTEIN: 40]\n[DEFAULT DNA: 40]")), ToolInput(tag="in_wether_overlap_calculated", input_type=Boolean(optional=True), prefix="-o", doc=InputDocumentation(doc="wether overlap weights are calculated or not [DEFAULT 0]")), ToolInput(tag="in_minimum_fragment_length", input_type=Boolean(optional=True), prefix="-f", doc=InputDocumentation(doc="minimum fragment length [DEFAULT 1]")), ToolInput(tag="in_threshold_weight_consider", input_type=Boolean(optional=True), prefix="-r", doc=InputDocumentation(doc="threshold weight to consider the fragment at all [DEFAULT 0.0]")), ToolInput(tag="in_only_use_stripe", input_type=Boolean(optional=True), prefix="-u", doc=InputDocumentation(doc="[DEFAULT 0]\n1: only use a sqrt(amount_of_seqs) stripe of neighbour\nsequences to calculate pairwise alignments (increase performance)\n0: all pairwise alignments will be calculated")), ToolInput(tag="in_optional_anchor_file", input_type=Boolean(optional=True), prefix="-A", doc=InputDocumentation(doc="optional anchor file [DEFAULT none]")), ToolInput(tag="in_input_is_dnasequence", input_type=Boolean(optional=True), prefix="-D", doc=InputDocumentation(doc="input is DNA-sequence")), ToolInput(tag="in_translate_dna_end", input_type=Boolean(optional=True), prefix="-T", doc=InputDocumentation(doc="translate DNA into aminoacids from begin to end (length will be cut to mod 3 = 0)\nWARNING: Do not use -D with this option\n(Default values for PROTEIN input will be loaded)")), ToolInput(tag="in_compare_reading_framewarning", input_type=Boolean(optional=True), prefix="-L", doc=InputDocumentation(doc="compare only longest Open Reading Frame\nWARNING: Do not use -D with this option\n(Default values for PROTEIN input will be loaded)")), ToolInput(tag="in_translate_dna_aminoacids", input_type=Boolean(optional=True), prefix="-O", doc=InputDocumentation(doc="translate DNA to aminoacids, reading frame for each sequence calculated due to its longest ORF\nWARNING: Do not use -D with this option\n(Default values for PROTEIN input will be loaded)")), ToolInput(tag="in_output_aminoacids_retranslation", input_type=Boolean(optional=True), prefix="-P", doc=InputDocumentation(doc="output in aminoacids, no retranslation of DNA sequences\n[DEFAULT: input = output]")), ToolInput(tag="in_fast_mode_implies", input_type=Boolean(optional=True), prefix="-F", doc=InputDocumentation(doc="fast mode (implies -l0, since it already significantly reduces sensitivity)")), ToolInput(tag="in_generate_probability_table", input_type=Boolean(optional=True), prefix="-C", doc=InputDocumentation(doc="generate probability table saved in <config_dir>/prob_table and exit")), ToolInput(tag="in_this_message", input_type=String(optional=True), prefix="-H", doc=InputDocumentation(doc="this message")), ToolInput(tag="in_di_align_t", input_type=String(), position=0, doc=InputDocumentation(doc="")), ToolInput(tag="in_conf_directory", input_type=Directory(), position=1, doc=InputDocumentation(doc="")), ToolInput(tag="in_fast_a_file", input_type=File(), position=2, doc=InputDocumentation(doc="")), ToolInput(tag="in_fast_a_out_file", input_type=File(optional=True), position=3, doc=InputDocumentation(doc=""))], outputs=[ToolOutput(tag="out_fast_a_out_file", output_type=File(optional=True), selector=InputSelector(input_to_select="in_fast_a_out_file", type_hint=File()), doc=OutputDocumentation(doc=""))], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Dialign_Tx_V0_1_0().translate("wdl", allow_empty_container=True)

